@@ -1,5 +1,5 @@
 import time
-from .clients import hw_evs_client
+from .clients import hw_evs_client, hw_bss_client
 
 
 class HuaweiEvs:
@@ -93,3 +93,9 @@ class HuaweiEvs:
             time.sleep(sleep_interval)
         raise Exception("Waiting for server to be target state failed! the current state is {0}, "
                         "the target state is {1}".format(job_state, target_state))
+
+    def prepaid_resource(self):
+        return hw_bss_client.query_resource(self.id)
+
+    def cancel_resource(self):
+        return hw_bss_client.cancel_resource(self.id)
